/**
 * JOnAS: Java(TM) Open Application Server
 * Copyright (C) 2009 Bull S.A.
 * Contact: jonas-team@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id$
 * --------------------------------------------------------------------------
 */

package org.ow2.jonas.tests;

import java.io.ByteArrayOutputStream;
import java.io.IOException;
import java.io.InputStream;
import java.net.URL;

import org.junit.Assert;
import org.junit.Before;
import org.junit.Test;

/**
 * Tests the JOnAS - CARGO plug-in. This test is expected to work with JOnAS 4
 * and JOnAS 5 without any issues.
 * 
 * @author S. Ali Tokmen
 */
public class CargoTest {

    private static int TIMEOUT = 10;

    private int port;

    @Before
    public void setUp() {
        String webcontainerPort = System.getProperty("webcontainer.port");
        Assert.assertNotNull("webcontainer.port not set!", webcontainerPort);
        this.port = Integer.parseInt(webcontainerPort);
    }

    @Test
    public void testCargo() throws Exception {
        final URL url = new URL("http://localhost:" + port + "/cargocpc/index.html");
        final String expected = "Cargo Ping Component used to verify if the container is started.";

        String content = null;
        final long stopTime = System.currentTimeMillis() + CargoTest.TIMEOUT * 1000;
        while (System.currentTimeMillis() < stopTime) {
            Thread.sleep(1000);
            content = this.getContentAsString(url);
            if (content.contains(expected)) {
                break;
            }
        }

        Assert.assertTrue(content + " does not contain " + expected, content.contains(expected));
    }

    /**
     * Get the URL content as a String.
     * @param url the url
     * @return the URL content as a String
     * @throws IOException if an I/O exception occurs.
     */
    private String getContentAsString(final URL url) throws IOException {
        final InputStream inStream = url.openStream();
        final ByteArrayOutputStream bos = new ByteArrayOutputStream();
        try {
            int c;
            while ((c = inStream.read()) != -1) {
                bos.write(c);
            }
        } finally {
            inStream.close();
            bos.flush();
        }
        final String urlString = bos.toString();
        return urlString;
    }

}
